==> haskell-hsopenssl-0.11.4.14-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hsopenssl.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HsOpenSSL
version: 0.11.4.14
id: HsOpenSSL-0.11.4.14-9Jj3Luk8GSeBTDxc8hWMyM
key: HsOpenSSL-0.11.4.14-9Jj3Luk8GSeBTDxc8hWMyM
license: LicenseRef-PublicDomain
maintainer: Vladimir Shabanov <vshabanoff@gmail.com>
author: Adam Langley, Mikhail Vorozhtsov, PHO, Taru Karttunen
stability: stable
homepage: https://github.com/vshabanov/HsOpenSSL
synopsis: Partial OpenSSL binding for Haskell
description:
    .
    HsOpenSSL is an OpenSSL binding for Haskell. It can generate RSA
    and DSA keys, read and write PEM files, generate message digests,
    sign and verify messages, encrypt and decrypt messages. It has
    also some capabilities of creating SSL clients and servers.
    .
    This package is in production use by a number of Haskell based
    systems and stable. You may also be interested in the @tls@ package,
    <http://hackage.haskell.org/package/tls>, which is a pure Haskell
    implementation of SSL.
    .
category: Cryptography
abi: 3bd9b1fbf8fb8008496984c9940d224b
exposed: True
exposed-modules:
    OpenSSL OpenSSL.BN OpenSSL.Cipher OpenSSL.DER OpenSSL.DH
    OpenSSL.DSA OpenSSL.EVP.Base64 OpenSSL.EVP.Cipher
    OpenSSL.EVP.Digest OpenSSL.EVP.Internal OpenSSL.EVP.Open
    OpenSSL.EVP.PKey OpenSSL.EVP.Seal OpenSSL.EVP.Sign
    OpenSSL.EVP.Verify OpenSSL.PEM OpenSSL.PKCS7 OpenSSL.RSA
    OpenSSL.Random OpenSSL.Session OpenSSL.X509 OpenSSL.X509.Request
    OpenSSL.X509.Revocation OpenSSL.X509.Store
hidden-modules: OpenSSL.ASN1 OpenSSL.BIO OpenSSL.ERR
                OpenSSL.Objects OpenSSL.SSL.Option OpenSSL.Stack OpenSSL.Utils
                OpenSSL.X509.Name OpenSSL.DH.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/HsOpenSSL-0.11.4.14
library-dirs: /usr/lib/ghc-8.4.3/site-local/HsOpenSSL-0.11.4.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/HsOpenSSL-0.11.4.14
hs-libraries: HSHsOpenSSL-0.11.4.14-9Jj3Luk8GSeBTDxc8hWMyM
extra-libraries:
    crypto ssl
includes:
    openssl/asn1.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    network-2.7.0.1-Et5xinNKOyS9PBBSPunMFv time-1.8.0.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             network-2.7.0.1-Et5xinNKOyS9PBBSPunMFv=cced51d94580b834f4e10c7bd0dd5b4c
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
haddock-interfaces: /usr/share/doc/haskell-hsopenssl/html/HsOpenSSL.haddock
haddock-html: /usr/share/doc/haskell-hsopenssl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsopenssl-0.11.4.14-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hsopenssl.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HsOpenSSL
version: 0.11.4.14
id: HsOpenSSL-0.11.4.14-5nfJ5MdD6cBLFVJmp54Fg8
key: HsOpenSSL-0.11.4.14-5nfJ5MdD6cBLFVJmp54Fg8
license: LicenseRef-PublicDomain
maintainer: Vladimir Shabanov <vshabanoff@gmail.com>
author: Adam Langley, Mikhail Vorozhtsov, PHO, Taru Karttunen
stability: stable
homepage: https://github.com/vshabanov/HsOpenSSL
synopsis: Partial OpenSSL binding for Haskell
description:
    .
    HsOpenSSL is an OpenSSL binding for Haskell. It can generate RSA
    and DSA keys, read and write PEM files, generate message digests,
    sign and verify messages, encrypt and decrypt messages. It has
    also some capabilities of creating SSL clients and servers.
    .
    This package is in production use by a number of Haskell based
    systems and stable. You may also be interested in the @tls@ package,
    <http://hackage.haskell.org/package/tls>, which is a pure Haskell
    implementation of SSL.
    .
category: Cryptography
abi: 3f10bbfa6b83d1413651b7d3dd4d59aa
exposed: True
exposed-modules:
    OpenSSL OpenSSL.BN OpenSSL.Cipher OpenSSL.DER OpenSSL.DH
    OpenSSL.DSA OpenSSL.EVP.Base64 OpenSSL.EVP.Cipher
    OpenSSL.EVP.Digest OpenSSL.EVP.Internal OpenSSL.EVP.Open
    OpenSSL.EVP.PKey OpenSSL.EVP.Seal OpenSSL.EVP.Sign
    OpenSSL.EVP.Verify OpenSSL.PEM OpenSSL.PKCS7 OpenSSL.RSA
    OpenSSL.Random OpenSSL.Session OpenSSL.X509 OpenSSL.X509.Request
    OpenSSL.X509.Revocation OpenSSL.X509.Store
hidden-modules: OpenSSL.ASN1 OpenSSL.BIO OpenSSL.ERR
                OpenSSL.Objects OpenSSL.SSL.Option OpenSSL.Stack OpenSSL.Utils
                OpenSSL.X509.Name OpenSSL.DH.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/HsOpenSSL-0.11.4.14
library-dirs: /usr/lib/ghc-8.4.3/site-local/HsOpenSSL-0.11.4.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/HsOpenSSL-0.11.4.14
hs-libraries: HSHsOpenSSL-0.11.4.14-5nfJ5MdD6cBLFVJmp54Fg8
extra-libraries:
    crypto ssl
includes:
    openssl/asn1.h
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    network-2.7.0.2-2uNz8SJYvMr2FoPImv9yYz time-1.8.0.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             network-2.7.0.2-2uNz8SJYvMr2FoPImv9yYz=593cfbdab1e8a8c0dc553b5ae47d8025
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
haddock-interfaces: /usr/share/doc/haskell-hsopenssl/html/HsOpenSSL.haddock
haddock-html: /usr/share/doc/haskell-hsopenssl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
